A flutter debugging tool for the developers to manage the environments and widgets view testing.
Features
- A picture in picture button view which inspires from Flutter PIPView https://github.com/lslv1243/pip_view
- The button will open dev environment page
Getting started
flutter pub get jane
Usage
Add Jane wrapper at the top of home
class MyApp extends StatelessWidget {
const MyApp({super.key});
@override
Widget build(BuildContext context) {
return MaterialApp(
title: 'Flutter Demo',
theme: ThemeData(
colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
),
home: JaneWrapper(
builder: (context) {
return const MyHomePage(title: 'Flutter Demo Home Page');
},
contentNavigator: () {
Navigator.push(
context,
MaterialPageRoute(builder: (_) => DebugPage()),
);
},
),
);
}
}
Additional information
More information can be get from the original github of the PIPView https://github.com/lslv1243/pip_view